<?php

$container = $App->getParam('container');

$Backend = $App->getSession('Backend');
$App->setSession('Backend',$Backend);
$App->setSession('archive',$container);
$App->setSession('bennoIdTable',array());

exit;
?>
